:mod:`art.summary_writer`
=========================
.. automodule:: art.summary_writer

Base Class SummaryWriter
------------------------
.. autoclass:: SummaryWriter
   :members:

Summary Writer Default
-------------------------
.. autoclass:: SummaryWriterDefault
   :members:
   :special-members:
